==> configlinux-0.1.tar.gz: configlinux-0.1/configlinux/configabout.cpp <==
/***************************************************************************
                          configabout.cpp  -  description
                             -------------------
    begin                : Thu Jun 22 2000
    copyright            : (C) 2000 by Jae-Jun Lee
    email                : brucejr@samsung.co.kr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "configabout.h"

configAbout::configAbout(QWidget *parent, const char *name) : QDialog(parent,name,true){
	initDialog();
}

configAbout::~configAbout(){
}
/**  */
void configAbout::setDialogWindows(){
  QPixmap pm;
  pm.load(KApplication::kde_icondir() + "/sem2.bmp");
  SemLogoLabel->setPixmap(pm);

  DriverVer->setFrameStyle(QFrame::Panel | QFrame::Sunken );
  DriverVer->setLineWidth( 2 );
  DriverVer->setAlignment(AlignLeft);
  PrimFWVer->setFrameStyle(QFrame::Panel | QFrame::Sunken );
  PrimFWVer->setLineWidth( 2 );
  PrimFWVer->setAlignment(AlignLeft);
  SecondFWVer->setFrameStyle(QFrame::Panel | QFrame::Sunken );
  SecondFWVer->setLineWidth( 2 );
  SecondFWVer->setAlignment(AlignLeft);
  UtilityVer->setFrameStyle(QFrame::Panel | QFrame::Sunken );
  UtilityVer->setLineWidth( 2 );
  UtilityVer->setAlignment(AlignLeft);
  UtilityVer->setText("1.00");
  setCaption("About Linux Configuration Utility...");

  QObject::connect(OKButton,SIGNAL(clicked()),this,SLOT(accept()));
}
/**  */
void configAbout::setDriverVer(int DriverMajor,int DriverMinor){
  char buf[10];

  sprintf(buf,"%d.%d",DriverMajor,DriverMinor);
  DriverVer->setText(buf);

}
/**  */
void configAbout::setPRIVer(int Major,int Minor,int Variant){
   char buf[10];

  sprintf(buf,"%d.%d%d",Major,Minor,Variant);
  PrimFWVer->setText(buf);

}
/**  */
void configAbout::setSTAVer(int Major,int Minor,int Variant){
  char buf[10];

  sprintf(buf,"%d.%d%d",Major,Minor,Variant);
  SecondFWVer->setText(buf);

}

==> configlinux-0.2.tar.gz: configlinux-0.2/configlinux/configabout.cpp <==
/***************************************************************************
                          configabout.cpp  -  description
                             -------------------
    begin                : Thu Jun 22 2000
    copyright            : (C) 2000 by Jae-Jun Lee
    email                : brucejr@samsung.co.kr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "configabout.h"

configAbout::configAbout(QWidget *parent, const char *name) : QDialog(parent,name,true){
	initDialog();
}

configAbout::~configAbout(){
}
/**  */
void configAbout::setDialogWindows(){
  QPixmap pm;
  pm.load(KApplication::kde_icondir() + "/sem2.bmp");
  SemLogoLabel->setPixmap(pm);

//  DriverVer->setFrameStyle(QFrame::Panel | QFrame::Sunken );
//  DriverVer->setLineWidth( 2 );
  DriverVer->setAlignment(AlignLeft);
//  PrimFWVer->setFrameStyle(QFrame::Panel | QFrame::Sunken );
//  PrimFWVer->setLineWidth( 2 );
  PrimFWVer->setAlignment(AlignLeft);
//  SecondFWVer->setFrameStyle(QFrame::Panel | QFrame::Sunken );
//  SecondFWVer->setLineWidth( 2 );
  SecondFWVer->setAlignment(AlignLeft);
//  UtilityVer->setFrameStyle(QFrame::Panel | QFrame::Sunken );
//  UtilityVer->setLineWidth( 2 );
  UtilityVer->setAlignment(AlignLeft);
  UtilityVer->setText("1.20");
  setCaption("About Linux Configuration Utility...");

  QObject::connect(OKButton,SIGNAL(clicked()),this,SLOT(accept()));
}
/**  */
void configAbout::setDriverVer(int DriverMajor,int DriverMinor,int DriverVariant){
  char buf[10];

  sprintf(buf,"%d.%d%d",DriverMajor,DriverMinor,DriverVariant);
  DriverVer->setText(buf);

}
/**  */
void configAbout::setPRIVer(int Major,int Minor,int Variant){
   char buf[10];

  sprintf(buf,"%d.%d%d",Major,Minor,Variant);
  PrimFWVer->setText(buf);

}
/**  */
void configAbout::setSTAVer(int Major,int Minor,int Variant){
  char buf[10];

  sprintf(buf,"%d.%d%d",Major,Minor,Variant);
  SecondFWVer->setText(buf);

}
